<?xml version="1.0" encoding="ISO-8859-2"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" encoding="ISO-8859-2"/>

	<xsl:template match="/">
		<html>
			<head>
				<script>
					<xsl:attribute name="src"><xsl:value-of select="Site/config/script/@path"/><xsl:value-of select="Site/config/script/@file"/></xsl:attribute>
				</script>
				<script> 
					var path="<xsl:value-of select="Site/config/script/@path"/>";
				</script>
				<link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="Site/config/css/@path"/><xsl:value-of select="Site/config/css/@file"/></xsl:attribute></link>
			</head>
			<body>
				<xsl:if test="contains(Site/config/NavigationBar/@type,'dynamic')">
					<xsl:apply-templates select="Site/NavigationBar"/>
				</xsl:if>
				<xsl:if test="contains(Site/config/NavigationBar/@type,'static')">
					<xsl:call-template name="NavigationBar">
						<xsl:with-param name="type">static</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				<xsl:apply-templates select="Site/Title"/>
				<xsl:apply-templates select="Site/Enumeration | Site/Table"/>
				<xsl:if test="contains(Site/config/NavigationBar/@type,'dynamic')">
					<xsl:apply-templates select="Site/NavigationBar"/>
				</xsl:if>
				<xsl:apply-templates select="Site/Date"/>
				<xsl:if test="contains(Site/config/NavigationBar/@type,'static')">
					<xsl:call-template name="NavigationBar">
						<xsl:with-param name="type">static</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</body>
		</html>
	</xsl:template>

	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="Table" name="Table">
		<table align="center" border="1">
			<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			<xsl:attribute name="border"><xsl:value-of select="@border"/></xsl:attribute>
			<xsl:attribute name="cellspacing"><xsl:value-of select="@cellspacing"/></xsl:attribute>
			<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			<thead>
				<xsl:if test="not(contains(@type,'no_name'))">
					<tr>
						<th class="bigHeader">
							<xsl:attribute name="colspan"><xsl:value-of select="count(Record/*)"/></xsl:attribute>
							<xsl:value-of select="@name"/>
						</th>
					</tr>
				</xsl:if>
			</thead>
			<tbody>
				<tr>
					<xsl:for-each select="./Record[1]/*">
						<xsl:if test="not(contains(@type,'invisible'))">
							<th class="header">
								<xsl:value-of select="@name"/>
							</th>
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="count(./Record)=0">	
						<tr>
							<th>res tblzat</th>
						</tr>
					</xsl:if>
				</tr>
				<xsl:for-each select="./Record">
					<tr>
						<xsl:apply-templates select="@tooltip"/>
						<xsl:if test="position() mod 2=0">
							<xsl:attribute name="class">highlight</xsl:attribute>
						</xsl:if>
						<xsl:apply-templates select="."/>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
	</xsl:template>

	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="Enumeration">
		<table border="2" width="100%">
			<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			<thead>
				<tr>
					<xsl:if test="not(contains(@type,'no_name'))">
						<th colspan="2" class="bigHeader">
							<xsl:value-of select="@name"/>
						</th>
					</xsl:if>
				</tr>
			</thead>
			<tbody>
				<xsl:for-each select="./Record/*">
					<tr>
						<th class="header">
							<xsl:value-of select="@name"/>
						</th>
						<td>
							<xsl:apply-templates select="."/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
	</xsl:template>

	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="Record">
		<xsl:for-each select="./*">
			<xsl:if test="not(contains(@type,'invisible'))">
				<td valign="top">
					<xsl:attribute name="width"><xsl:number value="number(./@width)+30"/></xsl:attribute>
					<xsl:apply-templates select="."/>
				</td>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="Field" name="Field">
		<xsl:if test="contains(@type,'link')">
			<a>
				<xsl:attribute name="style">cursor:hand;</xsl:attribute>
				<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
				<xsl:attribute name="href"><xsl:value-of select="@path"/><xsl:value-of select="../child::*[@target='true']"/>.xml</xsl:attribute>
				<xsl:apply-templates select="@effect"/>
				<xsl:value-of select="."/>
			</a>
		</xsl:if>
		<xsl:if test="not(contains(@type,'link')) and not(contains(@type,'invisible'))">
			<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			<xsl:apply-templates select="@effect"/>
			<xsl:if test="contains(@class,'source')">
			  <pre><xsl:copy-of select="."/></pre>
			</xsl:if>
			<xsl:if test="not(contains(@class,'source'))">
				<xsl:copy-of select="."/>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="@effect">
		<xsl:attribute name="onMouseover">setHighlight(this,true)</xsl:attribute>
		<xsl:attribute name="onMouseout">setHighlight(this,false)</xsl:attribute>
	</xsl:template>
	
	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="@tooltip">
		<xsl:attribute name="title">
		<xsl:apply-templates select="../TooltipTable"/>
		</xsl:attribute>
	</xsl:template>

	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="DropdownTable">
		<img class="button" style="float: left;" alt="open/close"
						onmouseover="increase(this);" onmouseout="decrease(this);" onclick="changeVisibility(this);">
			<xsl:attribute name="src"><xsl:value-of select="/*/config/pictures/@path"/>/down.jpg</xsl:attribute>
		</img>
						
		<xsl:call-template name="Table"/>
	</xsl:template>
	
	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="TooltipTable">
<xsl:value-of select="./@name"/>:
<xsl:for-each select="./Record">
<xsl:for-each select="./*"> <xsl:value-of select="@name"/>: <xsl:value-of select="."/> /
</xsl:for-each>-----------------------------
</xsl:for-each>
	</xsl:template>
	
	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="Links">
		<xsl:for-each select="Record">
			<xsl:apply-templates select="Field"/>
			<xsl:if test="not(position()=last())">, </xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="Title">
		<div class="title bordered">
			<xsl:value-of select="@text1"/>
			<font class="title">
				<xsl:value-of select="."/>
			</font>
			<xsl:value-of select="@text2"/>
		</div>
	</xsl:template>
	
	<!-- /*******************************************************************************************************************************************/-->
	<xsl:template match="NavigationBar" name="NavigationBar">
		<xsl:param name="type"/>
		<table border="0" width="100%" class="bordered highlight NavigationBar" cellpadding="0" cellspacing="0">
				<tr>
					<xsl:if test="contains(@with,'back') or ($type='static')">
						<td width="16">
							<img class="button" title="Vissza" onclick="history.back();" width="16">
								<xsl:attribute name="src"><xsl:value-of select="/*/config/pictures/@path"/>/left.jpg</xsl:attribute>
							</img>
						</td>
						<th class="header" width="150" align="left">
							<a style="color:white; cursor:hand; text-decoration: underline" onclick="history.back();">Vissza</a>
						</th>
					</xsl:if>
					
					<td width="*" valign="top" align="center">
						<xsl:for-each select="/Site/config/Links/Link">
							<a>
								<xsl:attribute name="href"><xsl:value-of select="."/>.xml</xsl:attribute>
								<xsl:value-of select="@name"/>
							</a>
							<xsl:if test="position()!=last()"> -||- </xsl:if>
						</xsl:for-each>
					</td>
					
					<xsl:if test="contains(@with,'forward') or ($type='static')">
						<th class="header" width="150" align="right">
							<a style="color:white; cursor:hand; text-decoration: underline" onclick="history.forward();">Elre</a>
						</th>
						<td width="16">
							<img class="button" title="Elre" onclick="history.forward();" width="16">
								<xsl:attribute name="src"><xsl:value-of select="/*/config/pictures/@path"/>/rigth.jpg</xsl:attribute>
							</img>
						</td>
					</xsl:if>
				</tr>
				<xsl:if test="not($type='static')">
					<tr>
						<xsl:if test="contains(@with,'back')">
							<th class="header" width="16">
								<xsl:if test="child::Record/Field[.=../../../Current/Field]/../preceding-sibling::*[1]">
									<img class="button" title="Elz oldal" width="16">
										<xsl:attribute name="src"><xsl:value-of select="/*/config/pictures/@path"/>/up.jpg</xsl:attribute>
										<xsl:attribute name="onclick">
											document.location="<xsl:value-of select="child::Record/Field[.=../../../Current/Field]/../preceding-sibling::*[1]"/>.xml";
										</xsl:attribute>
									</img>
								</xsl:if>
							</th>
							<th class="header" width="150" align="left">
								<xsl:if test="child::Record/Field[.=../../../Current/Field]/../preceding-sibling::*[1]">
									<a style="color:white">
										<xsl:attribute name="href">
											<xsl:value-of select="child::Record/Field[.=../../../Current/Field]/../preceding-sibling::*[1]"/>.xml
										</xsl:attribute>
										Elz: <xsl:value-of select="child::Record/Field[.=../../../Current/Field]/../preceding-sibling::*[1]"/>
									</a>
								</xsl:if>
							</th>
						</xsl:if>
						<td  valign="top" align="center">
							<xsl:for-each select="./Record/Field">
								<xsl:apply-templates select="."/>
								<xsl:if test="not(position()=last())">, </xsl:if>
							</xsl:for-each>
						</td>
						<xsl:if test="contains(@with,'back')">
							<th class="header" width="150" align="right">
								<xsl:if test="child::Record/Field[.=../../../Current/Field]/../following-sibling::*">
									<a style="color:white">
										<xsl:attribute name="href">
											<xsl:value-of select="child::Record/Field[.=../../../Current/Field]/following::*"/>.xml
										</xsl:attribute>
										Kvetkez: <xsl:value-of select="child::Record/Field[.=../../../Current/Field]/following::*"/>
									</a>
								</xsl:if>
							</th>
							<th class="header" width="16">
								<xsl:if test="child::Record/Field[.=../../../Current/Field]/../following-sibling::*">
									<img class="button" title="Kvetkez oldal" onclick="history.forward();" width="16">
										<xsl:attribute name="onclick">
											document.location="<xsl:value-of select="child::Record/Field[.=../../../Current/Field]/../following-sibling::*"/>.xml";
										</xsl:attribute>
										<xsl:attribute name="src"><xsl:value-of select="/*/config/pictures/@path"/>/down.jpg</xsl:attribute>
									</img>
								</xsl:if>
							</th>
						</xsl:if>
					</tr>
				</xsl:if>
		</table>
	</xsl:template>
	
	<xsl:template match="Function">
		<code class="source"><xsl:value-of select="./*[@type='name']"/>(<xsl:value-of select="./*[@type='args']"/>)</code>
	</xsl:template>
	
	<xsl:template match="Date">
		<div align="right" class="value bordered">Generated by DBView: <xsl:value-of select="."/></div>
	</xsl:template>

</xsl:stylesheet>
